@@ -728,10 +728,14 @@ class Test_timestamp_to_json_row(unittest.TestCase):
         self.assertEqual(self._call_fut(ZULU), ZULU)
 
     def test_w_datetime(self):
-        from google.cloud._helpers import _microseconds_from_datetime
-
         when = datetime.datetime(2016, 12, 20, 15, 58, 27, 339328)
-        self.assertEqual(self._call_fut(when), _microseconds_from_datetime(when) / 1e6)
+        self.assertEqual(self._call_fut(when), "2016-12-20T15:58:27.339328Z")
+
+    def test_w_datetime_w_utc_zone(self):
+        from google.cloud._helpers import UTC
+
+        when = datetime.datetime(2020, 11, 17, 1, 6, 52, 353795, tzinfo=UTC)
+        self.assertEqual(self._call_fut(when), "2020-11-17T01:06:52.353795Z")
 
 
 class Test_datetime_to_json(unittest.TestCase):
